==> nui_form-0.0.29.tar.gz: lib/nuif_form_component.dart <==
import 'package:flutter/cupertino.dart';
import 'package:nui_core/nui_core.dart';
import 'package:nui_form/nuif_form.dart';

class NUIFormSelection extends NUIEnt<NUIFormSelection>{
  NUIFormSelection.empty();
  NUIFormSelection({this.code, this.value});
  String code;
  String value;

  @override
  NUIEntMapper<NUIFormSelection> mapper(){
    return NUIFormSelectionEntity();
  }
}
class NUIFormSelectionEntity extends NUIEntMapper<NUIFormSelection>{
  @override
  String entityName(){
    return "NUIFormSelection";
  }

  @override
  NUIFormSelection newInstance(){
    return NUIFormSelection.empty();
  }

  @override
  List<NUIEntField> fields(){
    return [
      NUIEntField<NUIFormSelection>(name: "code", type: NUIEntType.STRING, setter: (data, value) => data.code = value, getter: (data) => data.code),
      NUIEntField<NUIFormSelection>(name: "value", type: NUIEntType.STRING, setter: (data, value) => data.value = value, getter: (data) => data.value),
    ];
  }
}

class NUIFormValue extends NUIEnt<NUIFormValue>{
  NUIFormValue.empty();
  NUIFormValue({@required this.inpId, this.value, this.values, this.validated});
  String inpId;
  NUIFormSelection value;
  bool validated = false;
  List<NUIFormSelection> values;

  @override
  NUIEntMapper<NUIFormValue> mapper(){
    return NUIFormValueEntity();
  }
}
class NUIFormValueEntity extends NUIEntMapper<NUIFormValue>{
  @override
  String entityName(){
    return "NUIFormValue";
  }

  @override
  NUIFormValue newInstance(){
    return NUIFormValue.empty();
  }

  @override
  List<NUIEntField> fields(){
    return [
      NUIEntField<NUIFormValue>(name: "inpId", type: NUIEntType.STRING, setter: (data, value) => data.inpId = value, getter: (data) => data.inpId),
      NUIEntField<NUIFormValue>(name: "value", type: NUIEntType.OBJECT, setter: (data, value) => data.value = asObject(NUIFormSelectionEntity(), value), getter: (data) => data.value),
      NUIEntField<NUIFormValue>(name: "values", type: NUIEntType.LIST_OBJECT, setter: (data, value) => data.values = asListOfObjects(NUIFormSelectionEntity(), value), getter: (data) => data.values),
    ];
  }
}

abstract class NUIFormContainer extends NUIFormComponent{
  NUIFormContainer({
    @required this.items,
    @required String inpId,
    @required String inpType,
    double width,
    double height,
    double weight,
    bool enabled:true,
    EdgeInsets margin,
    Alignment align,
    NUIFormValue formValue
  })
  : super(inpId: inpId, inpType: inpType, width: width, height: height, weight: weight, enabled: enabled, margin: margin, formValue: formValue, align: align);
  List<NUIFormComponent> items;
  Map<String, GlobalKey> componentKeys;

  @override
  void extractValue(Map<String, NUIFormValue> map){
    items.forEach((comp) {
      comp.extractValue(map);
    });
  }

  @override
  bool validate(bool quiet){
    bool validated = true;
    items.forEach((comp) {
      validated = validated && comp.validate(quiet);
    });
    return validated;
  }
}

abstract class NUIFState<T extends StatefulWidget, D extends NUIFormComponent> extends State<T>{
  D item;

  @override
  void initState(){
    super.initState();
    item.stateGetter = (){
      return this;
    };
  }

  @override
  void dispose(){
    super.dispose();
    item.stateGetter = null;
  }

  void update(D item){
    setState(() {
      this.item = item;
    });
  }
}

abstract class NUIFormComponent{
  NUIFormComponent({@required this.inpId, @required this.inpType, this.width, this.height, this.weight, this.enabled:true, this.margin, this.formValue, this.align, this.compulsory:true, this.show: true});

  String inpId;
  String inpType;
  double width;
  double height;
  double weight;
  bool enabled;
  bool compulsory;
  bool show;
  Alignment align;
  EdgeInsets margin;
  NUIFormValue formValue;
  StateGetter stateGetter;

  double getFlex(){
    if(width == null || width <= 0){
      return weight ?? 1;
    }
    return null;
  }

  Widget toWidget({AllTextChangeListener allTextChangeListener, AllButtonClickListener allButtonClickListener, AllItemSelectListener allItemSelectListener, Key key});
  Widget wrapWidget(Widget widget){
    if(margin != null){
      return Container(
        child: widget,
        alignment: align,
        margin: margin,
      );
    }
    else{
      return Container(
        child: widget,
        alignment: align,
      );
    }
  }

  NUIFormComponent findItemById(String inpId){
    if(this is NUIFormContainer) {
      logNUI("NUIFormComp", "Finding component $inpId in container ${this.inpId}");
      for (NUIFormComponent f in (this as NUIFormContainer).items) {
        final itemFound = f.findItemById(inpId);
        if(itemFound != null) return itemFound;
      }
      return null;
    }
    logNUI("NUIFormComp", "Matching component $inpId with ${this.inpId}");
    return match(this.inpId, inpId) ? this : null;
  }

  void extractValue(Map<String, NUIFormValue> map);
  bool validate(bool quiet);
}

class ComponentType{
  ComponentType._builder();
  static const String TEXT = "TEXT";
  static const String DROPDOWN = "DROPDOWN";
  static const String ROW = "ROW";
  static const String COLUMN = "COLUMN";
  static const String LIST = "LIST";
  static const String CHECKBOX = "CHECKBOX";
  static const String RADIO = "RADIO";
  static const String CHECKGROUP = "CHECKGROUP";
  static const String CUSTOM = "CUSTOM";
}

==> nui_form-0.0.33.tar.gz: lib/nuif_form_component.dart <==
import 'package:flutter/cupertino.dart';
import 'package:nui_core/nui_core.dart';
import 'package:nui_form/nuif_form.dart';

class NUIFormSelection extends NUIEnt<NUIFormSelection>{
  NUIFormSelection.empty();
  NUIFormSelection({this.code, this.value});
  String code;
  String value;

  @override
  NUIEntMapper<NUIFormSelection> mapper(){
    return NUIFormSelectionEntity();
  }
}
class NUIFormSelectionEntity extends NUIEntMapper<NUIFormSelection>{
  @override
  String entityName(){
    return "NUIFormSelection";
  }

  @override
  NUIFormSelection newInstance(){
    return NUIFormSelection.empty();
  }

  @override
  List<NUIEntField> fields(){
    return [
      NUIEntField<NUIFormSelection>(name: "code", type: NUIEntType.STRING, setter: (data, value) => data.code = value, getter: (data) => data.code),
      NUIEntField<NUIFormSelection>(name: "value", type: NUIEntType.STRING, setter: (data, value) => data.value = value, getter: (data) => data.value),
    ];
  }
}

class NUIFormValue extends NUIEnt<NUIFormValue>{
  NUIFormValue.empty();
  NUIFormValue({@required this.inpId, this.value, this.values, this.validated});
  String inpId;
  NUIFormSelection value;
  bool validated = false;
  List<NUIFormSelection> values;

  @override
  NUIEntMapper<NUIFormValue> mapper(){
    return NUIFormValueEntity();
  }
}
class NUIFormValueEntity extends NUIEntMapper<NUIFormValue>{
  @override
  String entityName(){
    return "NUIFormValue";
  }

  @override
  NUIFormValue newInstance(){
    return NUIFormValue.empty();
  }

  @override
  List<NUIEntField> fields(){
    return [
      NUIEntField<NUIFormValue>(name: "inpId", type: NUIEntType.STRING, setter: (data, value) => data.inpId = value, getter: (data) => data.inpId),
      NUIEntField<NUIFormValue>(name: "value", type: NUIEntType.OBJECT, setter: (data, value) => data.value = asObject(NUIFormSelectionEntity(), value), getter: (data) => data.value),
      NUIEntField<NUIFormValue>(name: "values", type: NUIEntType.LIST_OBJECT, setter: (data, value) => data.values = asListOfObjects(NUIFormSelectionEntity(), value), getter: (data) => data.values),
    ];
  }
}

abstract class NUIFormContainer extends NUIFormComponent{
  NUIFormContainer({
    @required this.items,
    @required String inpId,
    @required String inpType,
    double width,
    double height,
    double weight,
    bool enabled:true,
    EdgeInsets margin,
    Alignment align,
    NUIFormValue formValue
  })
  : super(inpId: inpId, inpType: inpType, width: width, height: height, weight: weight, enabled: enabled, margin: margin, formValue: formValue, align: align);
  List<NUIFormComponent> items;
  Map<String, GlobalKey> componentKeys;

  @override
  void extractValue(Map<String, NUIFormValue> map){
    items.forEach((comp) {
      comp.extractValue(map);
    });
  }

  @override
  bool validate(bool quiet){
    bool validated = true;
    items.forEach((comp) {
      validated = validated && comp.validate(quiet);
    });
    return validated;
  }
}

abstract class NUIFState<T extends StatefulWidget, D extends NUIFormComponent> extends State<T>{
  D item;

  @override
  void initState(){
    super.initState();
    item.stateGetter = (){
      return this;
    };
  }

  @override
  void dispose(){
    super.dispose();
//    item.stateGetter = null;
  }

  void update(D item){
    setState(() {
      this.item = item;
    });
  }
}

abstract class NUIFormComponent{
  NUIFormComponent({@required this.inpId, @required this.inpType, this.width, this.height, this.weight, this.enabled:true, this.margin, this.formValue, this.align, this.compulsory:true, this.show: true});

  String inpId;
  String inpType;
  double width;
  double height;
  double weight;
  bool enabled;
  bool compulsory;
  bool show;
  Alignment align;
  EdgeInsets margin;
  NUIFormValue formValue;
  StateGetter stateGetter;

  double getFlex(){
    if(width == null || width <= 0){
      return weight ?? 1;
    }
    return null;
  }

  Widget toWidget({AllTextChangeListener allTextChangeListener, AllButtonClickListener allButtonClickListener, AllItemSelectListener allItemSelectListener, Key key});
  Widget wrapWidget(Widget widget){
    if(margin != null){
      return Container(
        child: widget,
        alignment: align,
        margin: margin,
      );
    }
    else{
      return Container(
        child: widget,
        alignment: align,
      );
    }
  }

  NUIFormComponent findItemById(String inpId){
    if(match(this.inpId, inpId)) return this;

    if(this is NUIFormContainer) {
      for (NUIFormComponent f in (this as NUIFormContainer).items) {
        final itemFound = f.findItemById(inpId);
        if(itemFound != null) return itemFound;
      }
      return null;
    }
    return null;
  }

  void extractValue(Map<String, NUIFormValue> map);
  bool validate(bool quiet);
}

class ComponentType{
  ComponentType._builder();
  static const String TEXT = "TEXT";
  static const String DROPDOWN = "DROPDOWN";
  static const String ROW = "ROW";
  static const String COLUMN = "COLUMN";
  static const String LIST = "LIST";
  static const String CHECKBOX = "CHECKBOX";
  static const String RADIO = "RADIO";
  static const String CHECKGROUP = "CHECKGROUP";
  static const String CUSTOM = "CUSTOM";
}
